# PageSize


## Enum

* `Small` (value: `10`)

* `Medium` (value: `20`)

* `Large` (value: `50`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


